==> nisje-wp-plugin-user-content-7.1.3.zip: user-content/taxonomies/taxonomy-nisje-user-content-type.php <==
<?php
/**
 * Setup Type Taxonomy
 *
 * @package Nisje
 */

defined( 'ABSPATH' ) || die( 'Shame on you' );

$cap            = nisje_get_setting( 'capability_key', 'user-content' );
$post_type_name = nisje_get_setting( 'post_type_name', 'user-content' );
$taxonomy_name  = nisje_get_setting( 'taxonomy_type_name', 'user-content' );

$taxonomy_args = [
	'labels'            => [
		'name'              => esc_html_x( 'Types', 'taxonomy general name', 'nisje-user-content' ),
		'singular_name'     => esc_html_x( 'Type', 'taxonomy singular name', 'nisje-user-content' ),
		'search_items'      => esc_html__( 'Search types', 'nisje-user-content' ),
		'all_items'         => esc_html__( 'All types', 'nisje-user-content' ),
		'parent_item'       => esc_html__( 'Parent', 'nisje-user-content' ),
		'parent_item_colon' => esc_html__( 'Parent:', 'nisje-user-content' ),
		'edit_item'         => esc_html__( 'Edit', 'nisje-user-content' ),
		'update_item'       => esc_html__( 'Update', 'nisje-user-content' ),
		'add_new_item'      => esc_html__( 'Add New Type', 'nisje-user-content' ),
		'new_item_name'     => esc_html__( 'New Type Name', 'nisje-user-content' ),
		'menu_name'         => esc_html__( 'Types', 'nisje-user-content' ),
	],
	'hierarchical'      => false,
	'show_admin_column' => false,
	'show_ui'           => true,
	'query_var'         => false,
	'rewrite'           => false,
	'capabilities'      => [
		// Not allowed to edit or delete.
		'manage_terms' => '',
		'edit_terms'   => '',
		'delete_terms' => '',
		// Allow assigning terms.
		'assign_terms' => 'edit_posts',
	],
	'show_in_rest'      => false,
];

/**
 * Filters the taxonomy arguments for this taxonomy.
 *
 * @param array $taxonomy_args Taxonomy arguments.
 */
$taxonomy_args = apply_filters( 'nisje_taxonomy_user_content_type_args', $taxonomy_args );

/**
 * Filters the object types to connect to this taxonomy.
 *
 * @param array $post_types Post type arguments.
 */
$post_types   = [ $post_type_name ];
$object_types = apply_filters( 'nisje_taxonomy_user_content_type_object_types', $post_types );

register_taxonomy( $taxonomy_name, $object_types, $taxonomy_args );

==> nisje-wp-plugin-user-content-9.1.0.zip: user-content/taxonomies/taxonomy-nisje-user-content-type.php <==
<?php
/**
 * Setup Type Taxonomy
 *
 * @package Nisje
 */

defined( 'ABSPATH' ) || die( 'Shame on you' );

$cap            = nisje_get_setting( 'capability_key', 'user-content' );
$post_type_name = nisje_get_setting( 'post_type_name', 'user-content' );
$taxonomy_name  = nisje_get_setting( 'taxonomy_type_name', 'user-content' );

$taxonomy_args = [
	'labels'            => [
		'name'              => esc_html_x( 'Types', 'taxonomy general name', 'nisje' ),
		'singular_name'     => esc_html_x( 'Type', 'taxonomy singular name', 'nisje' ),
		'search_items'      => esc_html__( 'Search types', 'nisje' ),
		'all_items'         => esc_html__( 'All types', 'nisje' ),
		'parent_item'       => esc_html__( 'Parent', 'nisje' ),
		'parent_item_colon' => esc_html__( 'Parent:', 'nisje' ),
		'edit_item'         => esc_html__( 'Edit', 'nisje' ),
		'update_item'       => esc_html__( 'Update', 'nisje' ),
		'add_new_item'      => esc_html__( 'Add New Type', 'nisje' ),
		'new_item_name'     => esc_html__( 'New Type Name', 'nisje' ),
		'menu_name'         => esc_html__( 'Types', 'nisje' ),
	],
	'hierarchical'      => false,
	'show_admin_column' => false,
	'show_ui'           => true,
	'query_var'         => false,
	'rewrite'           => false,
	'capabilities'      => [
		// Not allowed to edit or delete.
		'manage_terms' => '',
		'edit_terms'   => '',
		'delete_terms' => '',
		// Allow assigning terms.
		'assign_terms' => 'edit_posts',
	],
	'show_in_rest'      => false,
];

/**
 * Filters the taxonomy arguments for this taxonomy.
 *
 * @param array $taxonomy_args Taxonomy arguments.
 */
$taxonomy_args = apply_filters( 'nisje_taxonomy_user_content_type_args', $taxonomy_args );

/**
 * Filters the object types to connect to this taxonomy.
 *
 * @param array $post_types Post type arguments.
 */
$post_types   = [ $post_type_name ];
$object_types = apply_filters( 'nisje_taxonomy_user_content_type_object_types', $post_types );

register_taxonomy( $taxonomy_name, $object_types, $taxonomy_args );
